# AOC
Tools to support in solving the advent of code puzzles (see https://adventofcode.com/)

Several Point related functions (including rotation, manhattan distance), iterating the adjacent points or fetching data in a smart way
